package com.ruoyi.web.controller.system;

import java.io.IOException;
import java.util.List;

import com.ruoyi.common.config.RuoYiConfig;
import com.ruoyi.common.core.domain.model.LoginUser;
import com.ruoyi.common.utils.SecurityUtils;
import com.ruoyi.common.utils.ServletUtils;
import com.ruoyi.common.utils.file.FileUploadUtils;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.system.domain.TPersonalPage;
import com.ruoyi.system.service.ITPersonalPageService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;
import org.springframework.web.multipart.MultipartFile;

/**
 * 个人页Controller
 * 
 * @author ruoyi
 * @date 2020-08-29
 */
@RestController
@RequestMapping("/system/personalPage")
public class TPersonalPageController extends BaseController
{
    @Autowired
    private ITPersonalPageService tPersonalPageService;

    /**
     * 查询个人页列表
     */
    @PreAuthorize("@ss.hasPermi('system:personalPage:list')")
    @GetMapping("/list")
    public TableDataInfo list(TPersonalPage tPersonalPage)
    {
        startPage();
        List<TPersonalPage> list = tPersonalPageService.selectTPersonalPageList(tPersonalPage);
        return getDataTable(list);
    }

    /**
     * 导出个人页列表
     */
    @PreAuthorize("@ss.hasPermi('system:personalPage:export')")
    @Log(title = "个人页", businessType = BusinessType.EXPORT)
    @GetMapping("/export")
    public AjaxResult export(TPersonalPage tPersonalPage)
    {
        List<TPersonalPage> list = tPersonalPageService.selectTPersonalPageList(tPersonalPage);
        ExcelUtil<TPersonalPage> util = new ExcelUtil<TPersonalPage>(TPersonalPage.class);
        return util.exportExcel(list, "page");
    }

    /**
     * 获取个人页详细信息
     */
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return AjaxResult.success(tPersonalPageService.selectTPersonalPageById(id));
    }

    /**
     * 新增个人页
     */
    @PreAuthorize("@ss.hasPermi('system:personalPage:add')")
    @Log(title = "个人页", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody TPersonalPage tPersonalPage)
    {
        return toAjax(tPersonalPageService.insertTPersonalPage(tPersonalPage));
    }

    /**
     * 修改个人页
     */
    @PreAuthorize("@ss.hasPermi('system:personalPage:edit')")
    @Log(title = "个人页", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody TPersonalPage tPersonalPage)
    {
        return toAjax(tPersonalPageService.updateTPersonalPage(tPersonalPage));
    }

    /**
     * 删除个人页
     */
    @PreAuthorize("@ss.hasPermi('system:personalPage:remove')")
    @Log(title = "个人页", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(tPersonalPageService.deleteTPersonalPageByIds(ids));
    }
    /**
     * 状态修改
     */
    @PreAuthorize("@ss.hasPermi('system:personalPage:edit')")
    @PutMapping("/changeEnable")
    public AjaxResult changeStatus(@RequestBody TPersonalPage tPersonalPage)
    {
        if (tPersonalPage == null){
            return AjaxResult.error("数据不能为空");
        }
        if (tPersonalPage.getId() <= 0){
            return AjaxResult.error("ID不能为空");
        }
        if (!tPersonalPage.getEnable().equals("0") && !tPersonalPage.getEnable().equals("1")){
            return AjaxResult.error("修改失败");
        }
        tPersonalPage.setUpdateBy(SecurityUtils.getUsername());
        return toAjax(tPersonalPageService.updateEnable(tPersonalPage));
    }


    /**
     * 头像上传
     */
    @PreAuthorize("@ss.hasPermi('system:personalPage:edit')")
    @PostMapping("/avatar")
    public AjaxResult avatar(@RequestParam("avatarfile") MultipartFile file, Long id) throws IOException {
        if (!file.isEmpty()) {
            String avatar = FileUploadUtils.upload(RuoYiConfig.getUploadPath(), file);

            if (tPersonalPageService.updateAvatar(id, avatar)) {
                AjaxResult ajax = AjaxResult.success();
                ajax.put("imgUrl", avatar);
                return ajax;
            }
        }
        return AjaxResult.error("上传图片异常，请联系管理员");
    }
}
