package com.ruoyi.web.controller.system;

import java.util.Date;
import java.util.List;

import com.ruoyi.common.core.domain.entity.SysUser;
import com.ruoyi.common.utils.SecurityUtils;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.system.domain.TTemplatePage;
import com.ruoyi.system.service.ITTemplatePageService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 个人页模板Controller
 * 
 * @author ruoyi
 * @date 2020-08-29
 */
@RestController
@RequestMapping("/system/templatePage")
public class TTemplatePageController extends BaseController
{
    @Autowired
    private ITTemplatePageService tTemplatePageService;

    /**
     * 查询个人页模板列表
     */
    @PreAuthorize("@ss.hasPermi('system:templatePage:list')")
    @GetMapping("/list")
    public TableDataInfo list(TTemplatePage tTemplatePage)
    {
        startPage();
        List<TTemplatePage> list = tTemplatePageService.selectTTemplatePageList(tTemplatePage);
        return getDataTable(list);
    }

    /**
     * 导出个人页模板列表
     */
    @PreAuthorize("@ss.hasPermi('system:templatePage:export')")
    @Log(title = "个人页模板", businessType = BusinessType.EXPORT)
    @GetMapping("/export")
    public AjaxResult export(TTemplatePage tTemplatePage)
    {
        List<TTemplatePage> list = tTemplatePageService.selectTTemplatePageList(tTemplatePage);
        ExcelUtil<TTemplatePage> util = new ExcelUtil<TTemplatePage>(TTemplatePage.class);
        return util.exportExcel(list, "page");
    }

    /**
     * 获取个人页模板详细信息
     */
    @PreAuthorize("@ss.hasPermi('system:templatePage:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return AjaxResult.success(tTemplatePageService.selectTTemplatePageById(id));
    }

    /**
     * 新增个人页模板
     */
    @PreAuthorize("@ss.hasPermi('system:templatePage:add')")
    @Log(title = "个人页模板", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@Validated @RequestBody TTemplatePage tTemplatePage)
    {
        return toAjax(tTemplatePageService.insertTTemplatePage(tTemplatePage));
    }

    /**
     * 修改个人页模板
     */
    @PreAuthorize("@ss.hasPermi('system:templatePage:edit')")
    @Log(title = "个人页模板", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@Validated @RequestBody TTemplatePage tTemplatePage)
    {
        tTemplatePage.setUpdateBy(SecurityUtils.getUsername());
        return toAjax(tTemplatePageService.updateTTemplatePage(tTemplatePage));
    }

    /**
     * 删除个人页模板
     */
    @PreAuthorize("@ss.hasPermi('system:templatePage:remove')")
    @Log(title = "个人页模板", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(tTemplatePageService.deleteTTemplatePageByIds(ids));
    }

    /**
     * 状态修改
     */
    @PreAuthorize("@ss.hasPermi('system:templatePage:edit')")
    @PutMapping("/changeEnable")
    public AjaxResult changeStatus(@RequestBody TTemplatePage tTemplatePage)
    {
        if (tTemplatePage == null){
            return AjaxResult.error("数据不能为空");
        }
        if (tTemplatePage.getId() <= 0){
            return AjaxResult.error("ID不能为空");
        }
        if (!tTemplatePage.getEnable().equals("0") && !tTemplatePage.getEnable().equals("1")){
            return AjaxResult.error("修改失败");
        }
        tTemplatePage.setUpdateBy(SecurityUtils.getUsername());
        return toAjax(tTemplatePageService.updateEnable(tTemplatePage));
    }
}
